<?php
/**
 * Tests QueryResult() functions.
 * This script is used during development of the class itself.
 * @author Sascha 'SieGeL' Pfalz <php@saschapfalz.de>
 * @package db_SQLite
 * @subpackage Examples
 * @version 0.20 (07-Aug-2010)
 * $Id: test_queryresult.php,v 1.1 2010/08/07 17:47:05 siegel Exp $
 * @license http://opensource.org/licenses/bsd-license.php BSD License
 * @filesource
 */
/**
 * Load in the general functions for all tests.
 */
require_once('functions.inc.php');

/** Define the name of the database to use for this example: */
define('SQLITEDB_TESTDB'  , '/tmp/test.dbf');

// Determine SAPI type
$d = WhichBR();

// Create new instance of class
$db = new db_SQLite();

// Before doing anything connect first!
$db->Connect(SQLITEDB_TESTDB);

if($d['SAPI'] != 'cli')
  {
  echo('<pre>');
  }

echo($d['LF'].'QueryResult() Test for SQLite class'.$d['LF'].$d['LF']);

$test_table = <<<SQL
CREATE TABLE DB_SQLITE_T1
  (
  ID      INTEGER PRIMARY KEY,
  VALUE   VARCHAR(100)
  )
SQL;

CheckForDBobject($db,"DB_SQLITE_T1",$test_table);

// Fetch the list of existing objects inside our database:
$query=<<<EOM
SELECT name FROM
   (
    SELECT * FROM sqlite_master
    UNION ALL
    SELECT * FROM sqlite_temp_master
   )
WHERE type='table'
ORDER BY name
EOM;
$stmt = $db->QueryResult($query);
$rows = $db->NumRows($stmt);
printf("%d table(s) found in database %s%s%s",$rows,SQLITEDB_TESTDB,$d['LF'],$d['LF']);
$lv = 1;
while($t = $db->FetchResult($stmt))
  {
  printf("Tablename.%d=%s %s",$lv,$t['name'],$d['LF']);
  $lv++;
  }
$db->FreeResult($stmt);

printf("%sNow adding 10 rows of random data and reading them: %s%s",$d['LF'],$d['LF'],$d['LF']);
for($i = 0; $i < 10; $i++)
  {
  $random = mt_rand(0,99999);
  $db->Query("INSERT INTO DB_SQLITE_T1(VALUE) VALUES(".$random.")");
  }
printf("Ok, 10 rows added.%s%s",$d['LF'],$d['LF']);
$stmt = $db->QueryResult("SELECT ID,VALUE FROM DB_SQLITE_T1");
while($t = $db->FetchResult($stmt))
  {
  printf("ID=%05s | VALUE=%s%s",$t['ID'],$t['VALUE'],$d['LF']);
  }
$db->FreeResult($stmt);

// Finally we drop the table:
$db->Query("DROP TABLE DB_SQLITE_T1");

DBFooter($d['LF'],$db);

echo($d['LF']);
exit;
?>
